bl_info = {
    "name": "Plane with Alpha Texture",
    "blender": (3, 0, 0),
    "category": "Object",
    "description": "Creates a plane with an alpha texture",
    "author": "hardmancash",
    "version": (1, 1),
}

import bpy
from bpy.types import Operator, AddonPreferences, Panel
from bpy.props import IntProperty, StringProperty, EnumProperty

addon_keymaps = []

# Оператор для создания плоскости с альфа текстурой
class OBJECT_OT_create_plane_with_alpha_texture(Operator):
    bl_idname = "object.create_plane_with_alpha_texture"
    bl_label = "Create Plane with Alpha Texture"
    bl_description = "Creates a plane with an alpha texture"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        prefs = context.preferences.addons[__name__].preferences
        
        # Создаем плоскость
        bpy.ops.mesh.primitive_plane_add(size=2)
        plane = bpy.context.active_object
        
        # Создаем новый материал
        mat = bpy.data.materials.new(name="AlphaMaterial")
        mat.use_nodes = True
        bsdf = mat.node_tree.nodes.get("Principled BSDF")
        
        # Удаляем принципиальный BSDF, чтобы использовать Shader
        if bsdf:
            mat.node_tree.nodes.remove(bsdf)
        
        # Создаем новый shader
        shader = mat.node_tree.nodes.new(type="ShaderNodeBsdfTransparent")
        shader.location = (-300, 0)
        
        # Создаем текстурный узел изображения
        tex_image = mat.node_tree.nodes.new('ShaderNodeTexImage')
        tex_image.location = (-600, 0)
        
        # Создаем пустую текстуру с альфа-каналом
        width, height = prefs.texture_width, prefs.texture_height
        image = bpy.data.images.new("AlphaTexture", width=width, height=height, alpha=True)
        tex_image.image = image
        
        # Устанавливаем интерполяцию
        tex_image.interpolation = prefs.texture_interpolation
        
        # Создаем узел вывода материала
        material_output = mat.node_tree.nodes.get('Material Output')
        
        # Связываем узлы
        mat.node_tree.links.new(tex_image.outputs['Color'], shader.inputs['Color'])
        mat.node_tree.links.new(shader.outputs['BSDF'], material_output.inputs['Surface'])
        
        # Применяем материал к плоскости
        if plane.data.materials:
            plane.data.materials[0] = mat
        else:
            plane.data.materials.append(mat)
        
        self.report({'INFO'}, "Plane with alpha texture created!")
        return {'FINISHED'}

# Панель для настроек в Sidebar
class OBJECT_PT_alpha_texture_panel(Panel):
    bl_label = "Alpha Texture Settings"
    bl_idname = "OBJECT_PT_alpha_texture_panel"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Tool'
    
    def draw(self, context):
        layout = self.layout
        prefs = context.preferences.addons[__name__].preferences

        layout.label(text="Texture Resolution")
        layout.prop(prefs, "texture_width")
        layout.prop(prefs, "texture_height")
        layout.label(text="Texture Interpolation")
        layout.prop(prefs, "texture_interpolation")

# Настройки аддона
class AlphaTextureAddonPreferences(AddonPreferences):
    bl_idname = __name__

    texture_width: IntProperty(
        name="Texture Width",
        default=1024,
        min=1,
    )
    texture_height: IntProperty(
        name="Texture Height",
        default=1024,
        min=1,
    )
    texture_interpolation: EnumProperty(
        name="Texture Interpolation",
        items=[
            ('Linear', "Linear", ""),
            ('Closest', "Closest", ""),
            ('Cubic', "Cubic", ""),
            ('Smart', "Smart", "")
        ],
        default='Linear',
    )
    hotkey: StringProperty(
        name="Hotkey",
        default="CTRL+SHIFT+P",
        description="Hotkey to create plane with alpha texture",
        update=lambda self, context: update_hotkey()
    )

    def draw(self, context):
        layout = self.layout
        layout.label(text="Texture Settings")
        layout.prop(self, "texture_width")
        layout.prop(self, "texture_height")
        layout.prop(self, "texture_interpolation")
        
        layout.label(text="Hotkey Settings")
        layout.prop(self, "hotkey")

def update_hotkey():
    # Удаление старых горячих клавиш
    for km, kmi in addon_keymaps:
        km.keymap_items.remove(kmi)
    addon_keymaps.clear()

    # Настройка новой горячей клавиши
    prefs = bpy.context.preferences.addons[__name__].preferences
    hotkey = prefs.hotkey.split("+")
    key = hotkey[-1]
    ctrl = "CTRL" in hotkey
    shift = "SHIFT" in hotkey
    alt = "ALT" in hotkey

    wm = bpy.context.window_manager
    km = wm.keyconfigs.addon.keymaps.new(name='Object Mode', space_type='EMPTY')
    kmi = km.keymap_items.new(OBJECT_OT_create_plane_with_alpha_texture.bl_idname, key, 'PRESS', ctrl=ctrl, shift=shift, alt=alt)
    addon_keymaps.append((km, kmi))

# Регистрация и отмена регистрации
def register():
    bpy.utils.register_class(OBJECT_OT_create_plane_with_alpha_texture)
    bpy.utils.register_class(OBJECT_PT_alpha_texture_panel)
    bpy.utils.register_class(AlphaTextureAddonPreferences)
    
    update_hotkey()

def unregister():
    bpy.utils.unregister_class(OBJECT_OT_create_plane_with_alpha_texture)
    bpy.utils.unregister_class(OBJECT_PT_alpha_texture_panel)
    bpy.utils.unregister_class(AlphaTextureAddonPreferences)

    # Удаление горячей клавиши
    for km, kmi in addon_keymaps:
        km.keymap_items.remove(kmi)
    addon_keymaps.clear()

if __name__ == "__main__":
    register()
